# FastAPIwee
FastAPI + PeeWee = <3

## Using

Python >= 3.6 :snake:

## Installation

```python
pip install FastAPIwee
```

:tada:

## Documentation

Documentation can be found here: https://fastapiwee.qqmber.wtf

## Development

### Documentation

Documentation is made with [MkDocs](https://www.mkdocs.org) and [Material for MkDocs](https://squidfunk.github.io/mkdocs-material/).

To run MkDocs server:

- Go to mkdocs directory

    ```bash
    cd mkdocs
    ```

- Run server

    ```bash
    mkdocs serve
    ```

To build use:

```bash
mkdocs build
```
